/********************
 * Stanford Law Review Paper Table 9
 * Two-Stage Least Squares Estimates of the Impact of Shall-Issue Laws
 * State Data
 * Lott coding
 * 1977-1992
 * 1977-1997
 ********************/


clear
set memory 20m
set matsize 700
set more off
log using "Table9.log", replace

use "complete 2sls dataset.dta", clear
drop if year>97

tab year, generate(yy) nof
tab fips, generate(ss) nof
tab region, generate(rr) nof

replace lvio=log(vio) if year==76
replace lpro=log(pro) if year==76
rename per_rep per_r

/* create change in crime rates variables */
gen vio_diff = lvio - lvio[_n-1] if fips==fips[_n-1]
gen pro_diff = lpro - lpro[_n-1] if fips==fips[_n-1]

drop if year==76

/* instruments = political vars */
ivreg lvio pb* pw* pn* rpc* ss* yy* densitym aovio stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", replace noparen nolabel  se bdec(5) coefastr 3aster
ivreg lpro pb* pw* pn* rpc* ss* yy* densitym aopro stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lmur pb* pw* pn* rpc* ss* yy* densitym aomur stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lrap pb* pw* pn* rpc* ss* yy* densitym aorap stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lrob pb* pw* pn* rpc* ss* yy* densitym aorob stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg laga pb* pw* pn* rpc* ss* yy* densitym aoaga stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lbur pb* pw* pn* rpc* ss* yy* densitym aobur stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg llar pb* pw* pn* rpc* ss* yy* densitym aolar stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg laut pb* pw* pn* rpc* ss* yy* densitym aoaut stpop (shalll = per_rep*) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster


/* instruments = political vars, crime rates, change in crime rates */
ivreg lvio pb* pw* pn* rpc* ss* yy* densitym aovio stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lpro pb* pw* pn* rpc* ss* yy* densitym aopro stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lmur pb* pw* pn* rpc* ss* yy* densitym aomur stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lrap pb* pw* pn* rpc* ss* yy* densitym aorap stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lrob pb* pw* pn* rpc* ss* yy* densitym aorob stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg laga pb* pw* pn* rpc* ss* yy* densitym aoaga stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lbur pb* pw* pn* rpc* ss* yy* densitym aobur stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg llar pb* pw* pn* rpc* ss* yy* densitym aolar stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg laut pb* pw* pn* rpc* ss* yy* densitym aoaut stpop (shalll = per_rep* vio_diff pro_diff lvio lpro) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster

/* instruments = political vars, change in crime rates */
ivreg lvio pb* pw* pn* rpc* ss* yy* densitym aovio stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lpro pb* pw* pn* rpc* ss* yy* densitym aopro stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lmur pb* pw* pn* rpc* ss* yy* densitym aomur stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lrap pb* pw* pn* rpc* ss* yy* densitym aorap stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lrob pb* pw* pn* rpc* ss* yy* densitym aorob stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg laga pb* pw* pn* rpc* ss* yy* densitym aoaga stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg lbur pb* pw* pn* rpc* ss* yy* densitym aobur stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg llar pb* pw* pn* rpc* ss* yy* densitym aolar stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster
ivreg laut pb* pw* pn* rpc* ss* yy* densitym aoaut stpop (shalll = per_rep* vio_diff pro_diff) [aw=stpop], robust
outreg shalll using "Table9.xls", append noparen nolabel  se bdec(5) coefastr 3aster

log close

